@@ -138,13 +138,32 @@ Instead, you may pass in an already-opened DBI handle to your database.
      Handle => $dbh
  };
 
-=head1 AUTHOR
-
-This module was written by Mike Langen <mike.langen@tamedia.ch>, based
-on the original for Oracle.
-
 =head1 SEE ALSO
 
 L<Apache::Session>, L<Apache::Session::Store::DBI>
-1;
 
+=head1 COPYRIGHT AND LICENSE
+
+=encoding utf8
+
+Copyright (C):
+
+=over
+
+=item 2009-2025 by Xavier Guimard
+
+=item 2013-2025 by Clément Oudot
+
+=item 2019-2025 by Maxime Besson
+
+=item 2013-2025 by Worteks
+
+=item 2023-2025 by Linagora
+
+=back
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.1 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
